@@ -91,19 +91,17 @@ class LoadApplicationLayer(ffd.ApplicationService):
                 self._deferred.append(('query', built, params))
 
     def _register_service(self, cls: Type[ffd.ApplicationService], context: ffd.Context):
-        if cls.is_agent():
-            self._agent_factory.register(cls.get_agent(), context.container.build(cls))
-
         if not cls.is_handler():
             return
 
         if cls.is_event_listener() and issubclass(cls, ffd.ApplicationService):
             for event in cls.get_events():
                 if isinstance(event, str):
-                    context_name = event
+                    context_name = event.split('.')[0]
                 else:
                     context_name = event.get_class_context()
-                if 'extends' in context.config and context_name != context.name:
+                if 'extends' in context.config and \
+                        (context_name == context.config.get('extends') or context_name == 'firefly'):
                     if isinstance(event, str):
                         event = f'{context.name}.{event.split(".")[-1]}'
                     else:
